pub struct BreakpointLocation {
pub column: Option<i64>,
pub end_column: Option<i64>,
pub end_line: Option<i64>,
pub line: i64,
}Expand description
Properties of a breakpoint location returned from the ‘breakpointLocations’ request.
Fields
column: Option<i64>Optional start column of breakpoint location.
end_column: Option<i64>Optional end column of breakpoint location if the location covers a range.
end_line: Option<i64>Optional end line of breakpoint location if the location covers a range.
line: i64Start line of breakpoint location.