pub struct BreakpointLocationsArguments {
pub column: Option<i64>,
pub end_column: Option<i64>,
pub end_line: Option<i64>,
pub line: i64,
pub source: Source,
}Expand description
Arguments for ‘breakpointLocations’ request.
Fields
column: Option<i64>Optional start column of range to search possible breakpoint locations in. If no start column is given, the first column in the start line is assumed.
end_column: Option<i64>Optional end column of range to search possible breakpoint locations in. If no end column is given, then it is assumed to be in the last column of the end line.
end_line: Option<i64>Optional end line of range to search possible breakpoint locations in. If no end line is given, then the end line is assumed to be the start line.
line: i64Start line of range to search possible breakpoint locations in. If only the line is specified, the request returns all possible locations in that line.
source: SourceThe source location of the breakpoints; either ‘source.path’ or ‘source.reference’ must be specified.