pub struct GotoTarget {
pub column: Option<i64>,
pub end_column: Option<i64>,
pub end_line: Option<i64>,
pub id: i64,
pub instruction_pointer_reference: Option<String>,
pub label: String,
pub line: i64,
}Expand description
A GotoTarget describes a code location that can be used as a target in the ‘goto’ request. The possible goto targets can be determined via the ‘gotoTargets’ request.
Fields
column: Option<i64>An optional column of the goto target.
end_column: Option<i64>An optional end column of the range covered by the goto target.
end_line: Option<i64>An optional end line of the range covered by the goto target.
id: i64Unique identifier for a goto target. This is used in the goto request.
instruction_pointer_reference: Option<String>Optional memory reference for the instruction pointer value represented by this target.
label: StringThe name of the goto target (shown in the UI).
line: i64The line of the goto target.